#
# spec file for package gojq
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gojq
Version:        0.12.17
Release:        1.3
Summary:        Pure Go implementation of jq
License:        MIT
URL:            https://github.com/itchyny/gojq
Source0:        %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
Source2:        gojq.rpmlintrc
BuildRequires:  go >= 1.21
BuildRequires:  golang-packaging
BuildRequires:  zstd

%description
Pure Go implementation of jq.

%prep
%autosetup -p1 -a1

%build
%ifarch ppc64
BUILDMODE=''
%else
BUILDMODE='-buildmode=pie'
%endif
go build -a -v -x -mod=vendor $BUILDMODE ./cmd/gojq

%install
install -D -m0755 %{name} %{buildroot}%{_bindir}/%{name}
install -D -m0644 _%{name} %{buildroot}%{_datadir}/zsh/site-functions/_%{name}

%check
%gotest ./...

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}

%changelog
* Sun Dec  1 2024 Arnav Singh <opensuse@arnavion.dev>
- Update to v0.12.17
  * Implement `add/1`, `skip/2` functions.
  * Implement `--library-path` option as the alias of `-L` option.
  * Fix `reduce` syntax to emit results for each initial value.
  * Fix `last/1` to yield no values when the argument yields no values.
  * Fix `limit/2` to emit an error on negative count.
  * Fix `@uri` and `@urid` formats not to convert space between plus sign.
  * Fix resolving search paths of import statements in the query.
  * Improve time functions to accept fewer element arrays.
* Sat Jun  1 2024 Arnav Singh <opensuse@arnavion.dev>
- Update to v0.12.16
  * Fix offset of query parsing error on multi-byte characters.
  * Fix tests of `exp10` and `atan2` failing on some platforms.
  * Fix `debug/1` to be available only when `debug/0` is defined.
  * Improve parser to allow binary operators as object values.
  * Improve compiler to emit error if query is missing.
* Mon Apr  1 2024 Arnav Singh <opensuse@arnavion.dev>
- Suppress rpmlint error statically-linked-binary.
- Fix rpmlint warning no-%%check-section.
* Mon Apr  1 2024 Arnav Singh <opensuse@arnavion.dev>
- Update to v0.12.15
  * Implement `ltrim`, `rtrim`, and `trim` functions.
  * Fix object construction with duplicate keys (`{x:0,y:1} | {a:.x,a:.y}`)
  * Fix `halt` and `halt_error` functions to stop the command execution
    immediately.
  * Fix variable scope of binding syntax
    (`"a" as $v | def f: $v; "b" as $v | f`).
  * Fix pre-defined variables to be available in initial modules
    (`$ARGS` in `~/.jq`).
  * Fix `ltrimstr` and `rtrimstr` functions to emit error on non-string input.
  * Fix `nearbyint` and `rint` functions to round ties to even.
  * Improve parser to allow `reduce`, `foreach`, `if`, `try`-`catch` syntax
    as object values.
  * Remove `pow10` in favor of `exp10`, define `scalbn` and `scalbln`
    by `ldexp`.
* Fri Dec  1 2023 Arnav Singh <opensuse@arnavion.dev>
- Update to v0.12.14
  * Implement `abs`, `pick` and `debug/1` functions.
  * Implement `--raw-output0` option, and remove `--nul-output` (`-0`) option.
  * Fix string multiplication by zero to emit an empty string.
  * Fix zero divided by zero to emit an error, not `nan`.
  * Fix modulo operator to emit `nan` if either side is `nan`.
  * Fix `implode` function to emit replacement characters on
    invalid code points.
  * Fix `stderr` function to output strings in raw format.
  * Fix `error` function to throw an error even for `null`.
  * Fix `walk` function on multiple outputs arguments.
  * Fix `--from-file` option to work with `--arg` and `--argjson` options.
  * Improve query parser to support comment continuation with backslash.
  * Improve `modulemeta` function to include defined function names in
    the module.
  * Improve search path of `import` and `include` directives to support
    `$ORIGIN` expansion.
  * Remove deprecated `leaf_paths` function.
* Thu Jun  1 2023 Arnav Singh <opensuse@arnavion.dev>
- Update vendor tarball.
* Thu Jun  1 2023 Arnav Singh <opensuse@arnavion.dev>
- Update to v0.12.13
  * Implement `@urid` format string to decode URI values.
  * Fix some functions returning arrays to emit empty slices instead of nil.
* Sat May 13 2023 Arnav Singh <opensuse@arnavion.dev>
- Restrict minumum golang version to the one listed in go.mod
* Sat May 13 2023 Arnav Singh <opensuse@arnavion.dev>
- Disable -buildmode=pie on ppc64, and add some verbosity flags.
* Fri May 12 2023 Arnav Singh <opensuse@arnavion.dev>
- Initial package of 0.12.12 for OpenSUSE.
